#
# spec file for package extension-manager
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid com.mattjakeman.ExtensionManager
Name:           extension-manager
Version:        0.6.0
Release:        2.1
Summary:        A utility for browsing and installing GNOME Shell Extensions
License:        GPL-3.0-or-later
URL:            https://github.com/mjakeman/extension-manager
Source0:        %{name}-%{version}.tar.gz
BuildRequires:  desktop-file-utils
BuildRequires:  gcc-c++
BuildRequires:  libbacktrace-devel
BuildRequires:  meson
BuildRequires:  pkgconfig(blueprint-compiler)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libadwaita-1)
BuildRequires:  pkgconfig(libsoup-3.0)
BuildRequires:  pkgconfig(libxml-2.0)

%description
A native tool for browsing, installing, and managing GNOME Shell Extensions.

%lang_package

%prep
%autosetup

%build
export CFLAGS="%{optflags} -Wno-error=return-type"
%meson
%meson_build

%install
%meson_install

%find_lang %{name}

%files
%license COPYING
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_datadir}/icons/hicolor/scalable/apps/%{appid}.svg
%{_datadir}/icons/hicolor/symbolic/apps/%{appid}-symbolic.svg
%{_datadir}/metainfo/%{appid}.metainfo.xml

%files lang -f %{name}.lang

%changelog
* Wed Dec 11 2024 Richard Rahl <rrahl0@opensuse.org>
- fix license
* Fri Dec  6 2024 rrahl0@opensuse.org
- Update to version 0.6.0:
  * po: Update German translation
  * po: Update Finnish translation
  * po: Update Ukrainian translation
  * po: Update German translation
  * po: Update Chinese (Traditional Han script) translation
  * po: Update Ukrainian translation
* Sun Nov 24 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.5.1+244:
  * general: Handle not found errors with empty page
  * local: Regenerate shell-dbus-interface
  * cleanup: Add and update license headers
  * installed-page: Add local search
  * manager: Unify user and system extensions list property
  * resource: Make path dependent on app_id
  * comment-dialog: Add license header
  * comment-dialog: Improve network error handling
  * upgrade-assistant: Improve network error handling
  * detail-view: Improve network error handling
  * browse-page: Improve network error handling
  * workflows: Add missing libxml2 dependency
  * drop text-engine
  * request-handler: Handle http status code
  * readme: Update dependencies
  * comment: Use the new HTML viewer
  * utils: Introduce a simple HTML viewer
  * comment-tile: Use GtkLabel as a comment text viewer
  * browse-page: Port load more results button to AdwButtonRow
  * rating: Fix warnings when finalizing with remaining child widgets
  * comment-tile: Fix warnings when finalizing with remaining child widgets
  * upgrade-assistant: g_print -> g_info
  * window: Stop manually setting a shortcut controller
  * detail-view: Remove unused variables
  * window: Stop explicitly setting toast timeout
  * window: Drop unused version check code
  * accessibility improvements
  * browse-page: Focus first new row after loading more results
  * window: Add mnemonic to toast button
  * info-bar: Rework items into AdwActionRow
  * rating: Add tooltip
  * extension-row: Hide version label if unavailable
  * extension-row: Improve accessibility
  * upgrade-assistant: Improve accessibility
  * detail-view: Improve accessibility
  * screenshot: Set accessible role
  * installed-page: Port updates info bar to AdwBanner
  * browse-page: Remove unused header
  * browse-page: Use search entry setter
  * browse-page: Enable type-ahead search
  * search-row: Remove unused import
  * local: Add support for version-name
  * window: Show badge number when updates are available
  * browse-page: Increase search-delay value
  * app: Add back help overlay
  * icons: Remove zoom symbolics
  * app: Fix criticals in master runtime
  * backtrace: Fix incompatible pointer types
  * comment-tile: Adapt to text-engine changes
  * Update com.mattjakeman.ExtensionManager.desktop.in.in
  * comment-tile: Add date label
  * comment: Add date property
  * Display info icon for Initialized/Inactive extension state
  * Set the extension state as a tooltip for extension toggle button
  * detail-view: Add donation row
  * search-result: Add donation urls property
  * Fix some warnings
* Fri Nov 22 2024 Richard Rahl <rrahl0@opensuse.org>
- fix CFLAGS, as with the earlier try, there was a typo with optflags
* Sun Aug 25 2024 Richard Rahl <rrahl0@opensuse.org>
- fix gcc14 by using "-Wno-error -Wno-unused-variable -Wno-unused-parameter
  - Wno-incompatible-pointer-types -Wno-return-mismatch -Wno-int-conversion"
* Thu May  2 2024 Richard Rahl <rrahl0@disroot.org>
- update to 0.5.1:
  * Add null checks for version parsing
  * backtrace: Collate 'null' messages
  * Use AdwPreferences* widgets
  * Fix crash on close while loading
- update to 0.5.0:
  * New widgets, better resizing, cleaner look
  * Compatibility with GNOME 46
  * Display extension icons and statistics
  * Search is more reliable
* Fri Feb 23 2024 Richard Rahl <rrahl0@proton.me>
- fix spec for Factory
* Fri Feb 23 2024 Richard Rahl <rrahl0@proton.me>
- clean up spec file
* Thu Nov 16 2023 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.4.3:
  * Translations update.
* Wed Jun 21 2023 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.4.2:
  * upgrade-assistant: don't scroll horizontally on results.
  * misc: Tweak app icon and optimize symbolics.
  * Translations update.
* Fri May  5 2023 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.4.1:
  * Translations update.
* Thu Mar 30 2023 Dead Mozay <dead_mozay@opensuse.org>
- Initial package.
